-- Servo driver for a skid steering vehicle with an active castor/tailwheel/rudder
-- For a rover the castor must be controlable from -90 to 90 degrees to make pivot turning possible
--
-- The following parameters should be set:
--     
--     SERVO5_FUNCTION = 98 (Script 5)
--     SERVO6_FUNCTION = 99 (Script 6)
-- The castor servo/actuator should be connected to the autopilot's output5
--
-- CAUTION: This script only works for Rover/Boat


local K_SCRIPTING5 = 98 --inner left Motor
local K_SCRIPTING6 = 99 --inner right Motor
local CONTROL_OUTPUT_THROTTLE = 3
local CONTROL_OUTPUT_YAW = 4
local SERVO2_MAX = Parameter()
if not SERVO2_MAX:init('SERVO2_MAX') then
  gcs:send_text(6, 'get SERVO2_MAX Failed')
end

local SERVO3_MAX = Parameter()
if not SERVO3_MAX:init('SERVO3_MAX') then
  gcs:send_text(6, 'get SERVO3_MAX Failed')
end

local SERVO2_TRIM = Parameter()
if not SERVO2_TRIM:init('SERVO2_TRIM') then
  gcs:send_text(6, 'get SERVO2_TRIM Failed')
end

local SERVO3_TRIM = Parameter()
if not SERVO3_TRIM:init('SERVO3_TRIM') then
  gcs:send_text(6, 'get SERVO3_TRIM Failed')
end

local deadzone = 0.01
local InitialMaxPWM2 = param:get('SERVO2_MAX')
local InitialMaxPWM3 = param:get('SERVO3_MAX')
local InitialTrimPWM2 = param:get('SERVO2_TRIM')
local InitialTrimPWM3 = param:get('SERVO3_TRIM')
function update()
  
    -- retrieve high level steering and throttle control outputs from vehicle in -1 to +1 range
    local steering = vehicle:get_control_output(CONTROL_OUTPUT_YAW)
    local throttle = vehicle:get_control_output(CONTROL_OUTPUT_THROTTLE)
    if steering > 0 then
    	SERVO2_MAX:set(InitialTrimPWM2)
    else 
    	SERVO2_MAX:set(InitialMaxPWM2)
    end
    	
    if steering < 0 then
    	SERVO3_MAX:set(InitialTrimPWM3)
    else
    	SERVO3_MAX:set(InitialMaxPWM3)
    end
	
	if steering > -deadzone and steering < deadzone then
		SERVO3_MAX:set(InitialMaxPWM3)
		SERVO2_MAX:set(InitialMaxPWM2)
	end
		

return update, 10 -- run at 100hz
end
gcs:send_text(6, "trimaran.lua is running")
return update()
